<?php

/**
 * Plugin Name: Tickera - Frontend Event Table Quantity Option
 * Plugin URI: https://tickera.com
 * Description: Unofficial add-on: Allow Quantity Option in the Frontend Event Table
 * Author: Tickera.com
 * Author URI: http://tickera.com/
 * Version: 1
 * Copyright 2017 Tickera (http://tickera.com/)
 */

if ( !class_exists( 'TC_Event_Table_Quantity_Option' ) ) {

    class TC_Event_Table_Quantity_Option
    {

        var $version = '1';
        var $title = 'Tickera Checkin - Webhook';
        var $name = 'tc-event-table-qty-option';
        var $dir_name = 'tc-event-table-qty-option';
        var $location = 'plugins';
        var $plugin_dir = '';
        var $plugin_url = '';

        function __construct()
        {
            self::init_vars();

            if ( class_exists( 'TC_WooCommerce_Bridge' ) ) {
                add_action( 'wp_enqueue_scripts', array( &$this, 'tc_enqueue_scripts' ) );
                add_action( 'tc_wb_event_col_title_before_cart_title', array( &$this, 'wb_quantity_option_column_title' ) );
                add_action( 'tc_wb_event_col_value_before_cart_title', array( &$this, 'wb_quantity_option_selector' ) );

            } else {
                add_filter( 'tc_event_shortcode', array( &$this, 'tc_enable_quantity_option' ) );
            }
        }

        function init_vars()
        {

            if (defined('WP_PLUGIN_URL') && defined('WP_PLUGIN_DIR') && file_exists(WP_PLUGIN_DIR . '/' . $this->dir_name . '/' . basename(__FILE__))) {
                $this->location = 'subfolder-plugins';
                $this->plugin_dir = WP_PLUGIN_DIR . '/' . $this->dir_name . '/';
                $this->plugin_url = plugins_url('/', __FILE__);

            } else if (defined('WP_PLUGIN_URL') && defined('WP_PLUGIN_DIR') && file_exists(WP_PLUGIN_DIR . '/' . basename(__FILE__))) {
                $this->location = 'plugins';
                $this->plugin_dir = WP_PLUGIN_DIR . '/';
                $this->plugin_url = plugins_url('/', __FILE__);

            } else if (is_multisite() && defined('WPMU_PLUGIN_URL') && defined('WPMU_PLUGIN_DIR') && file_exists(WPMU_PLUGIN_DIR . '/' . basename(__FILE__))) {
                $this->location = 'mu-plugins';
                $this->plugin_dir = WPMU_PLUGIN_DIR;
                $this->plugin_url = WPMU_PLUGIN_URL;
            } else {
                wp_die(sprintf(__('There was an issue determining where %s is installed. Please reinstall it.', 'tc'), $this->title));
            }
        }

        /**
         * Load Assets
         */
        function tc_enqueue_scripts() {
            wp_enqueue_script( $this->name, plugin_dir_url( __FILE__ ) . 'assets/js/' . $this->name . '.js', array( 'jquery' ), $this->version, true );
            wp_enqueue_style( $this->name, plugin_dir_url( __FILE__ ) . 'assets/css/' . $this->name . '.css', array(), $this->version );
        }

        function tc_enable_quantity_option() {
            return '[tc_event quantity="true"]';
        }

        function wb_quantity_option_column_title() {
            echo '<th>' . __( 'Qty.', 'tc' ) . '</th>';
        }

        function wb_quantity_option_selector( $ticket_type_id ) {
            echo '<td>' . self::wb_quantity_selector( $ticket_type_id ) . '</td>';
            echo '<td>' . '[add_to_cart id="' . $ticket_type_id . '" quantity="1" style="" show_price="false"]' . '</td>';
        }

        function wb_quantity_selector( $ticket_type_id ) {

            $max_quantity = 25;

            $product = wc_get_product( $ticket_type_id );
            $manage_stock = $product->get_manage_stock();
            $stock_status = $product->get_stock_status();

            if ( $manage_stock ) {
                $quantity = ( $product->get_stock_quantity() > $max_quantity ) ? $max_quantity : $product->get_stock_quantity();

            } else {
                $quantity = ( 'instock' == $stock_status ) ? $max_quantity : 0;
            }

            $select = '<select class="wb_quantity_selector">';

            if ( $quantity ) {

                for ( $i = 1; $i <= $quantity; $i++ ) {
                    $select .= '<option value="' . $i . '">';
                    $select .= $i;
                    $select .= '</option>';
                }

            } else {
                $select .= '<option value="0">0</option>';
            }

            return $select;
        }
    }

    $TC_Event_Table_Quantity_Option = new TC_Event_Table_Quantity_Option();
}